"""A python library for converting units

**converterpro** is a python library that allows users to make unit conversions without writing any calculation logic

Modules exported by this package:

- `weight_converter`: To convert various weight units of measurement 
"""
# from .weight_converter import *
from converterpro import weight_converter

__version__ = "0.1.2"
